@@ -1,6 +1,4 @@
-// The MIT License (MIT)
-//
-// Copyright (c) Itay Grudev 2015 - 2020
+// Copyright (c) Itay Grudev 2015 - 2023
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -9,6 +7,9 @@
 // copies of the Software, and to permit persons to whom the Software is
 // furnished to do so, subject to the following conditions:
 //
+// Permission is not granted to use this software or any of the associated files
+// as sample data for the purposes of building machine learning models.
+//
 // The above copyright notice and this permission notice shall be included in
 // all copies or substantial portions of the Software.
 //
@@ -32,10 +33,10 @@
 #ifndef SINGLEAPPLICATION_P_H
 #define SINGLEAPPLICATION_P_H
 
+#include "singleapplication.h"
 #include <QtCore/QSharedMemory>
 #include <QtNetwork/QLocalServer>
 #include <QtNetwork/QLocalSocket>
-#include "singleapplication.h"
 
 struct InstancesInfo {
     bool primary;
@@ -51,23 +52,25 @@ struct ConnectionInfo {
     quint8 stage = 0;
 };
 
-class SingleApplicationPrivate : public QObject {
-Q_OBJECT
+class SingleApplicationPrivate : public QObject
+{
+    Q_OBJECT
 public:
     enum ConnectionType : quint8 {
         InvalidConnection = 0,
         NewInstance = 1,
         SecondaryInstance = 2,
-        Reconnect = 3
+        Reconnect = 3,
     };
     enum ConnectionStage : quint8 {
-        StageHeader = 0,
-        StageBody = 1,
-        StageConnected = 2,
+        StageInitHeader = 0,
+        StageInitBody = 1,
+        StageConnectedHeader = 2,
+        StageConnectedBody = 3,
     };
     Q_DECLARE_PUBLIC(SingleApplication)
 
-    SingleApplicationPrivate( SingleApplication *q_ptr );
+    SingleApplicationPrivate(SingleApplication *q_ptr);
     ~SingleApplicationPrivate() override;
 
     static QString getUsername();
@@ -75,12 +78,16 @@ public:
     void initializeMemoryBlock() const;
     void startPrimary();
     void startSecondary();
-    bool connectToPrimary( int msecs, ConnectionType connectionType );
+    bool connectToPrimary(int msecs, ConnectionType connectionType);
     quint16 blockChecksum() const;
     qint64 primaryPid() const;
     QString primaryUser() const;
-    void readInitMessageHeader(QLocalSocket *socket);
+    bool isFrameComplete(QLocalSocket *sock);
+    void readMessageHeader(QLocalSocket *socket, ConnectionStage nextStage);
     void readInitMessageBody(QLocalSocket *socket);
+    void writeAck(QLocalSocket *sock);
+    bool writeConfirmedFrame(int msecs, const QByteArray &msg);
+    bool writeConfirmedMessage(int msecs, const QByteArray &msg, SingleApplication::SendMode sendMode = SingleApplication::NonBlocking);
     static void randomSleep();
     void addAppData(const QString &data);
     QStringList appData() const;
@@ -92,13 +99,13 @@ public:
     quint32 instanceNumber;
     QString blockServerName;
     SingleApplication::Options options;
-    QMap<QLocalSocket*, ConnectionInfo> connectionMap;
+    QMap<QLocalSocket *, ConnectionInfo> connectionMap;
     QStringList appDataList;
 
 public Q_SLOTS:
     void slotConnectionEstablished();
-    void slotDataAvailable( QLocalSocket*, quint32 );
-    void slotClientConnectionClosed( QLocalSocket*, quint32 );
+    void slotDataAvailable(QLocalSocket *, quint32);
+    void slotClientConnectionClosed(QLocalSocket *, quint32);
 };
 
 #endif // SINGLEAPPLICATION_P_H
